==> apgl-0.6.1.tar.gz: apgl-0.6.1/apgl/viroscopy/model/profile/HIVRatesProfile.py <==
import logging
import sys
import cProfile
import pstats
import numpy
import scipy
from apgl.viroscopy.model.HIVGraph import HIVGraph
from apgl.viroscopy.model.HIVRates import HIVRates
from apgl.viroscopy.model.HIVVertices import HIVVertices
from apgl.graph import *
from apgl.util import *

logging.basicConfig(stream=sys.stdout, level=logging.INFO)
numpy.random.seed(21)

class HIVRatesProfile():
    def __init__(self):
        #Total number of people in population
        self.M = 5000
        numInitialInfected = 5

        #The graph is one in which edges represent a contact
        #W = scipy.sparse.csr_matrix((self.M, self.M))
        W = scipy.sparse.lil_matrix((self.M, self.M))
        undirected = True
        self.graph = HIVGraph(self.M, undirected, W)

        for i in range(self.M):
            vertex = self.graph.getVertex(i)

            #Set the infection time of a number of individuals to 0
            if i < numInitialInfected:
                vertex[HIVVertices.stateIndex] = HIVVertices.infected

        outputDirectory = PathDefaults.getOutputDir()
        directory = outputDirectory + "test/"
        self.profileFileName = directory + "profile.cprof"


    def profileContactRate(self):
        susceptibleList = range(1, self.graph.getNumVertices())
        t = 10

        rates = HIVRates(self.graph)

        numContactEvents = 10000
        for i in range(numContactEvents):
            vertexInd1 = numpy.random.randint(0, self.graph.getNumVertices())
            vertexInd2 = numpy.random.randint(0, self.graph.getNumVertices())
            rates.contactEvent(vertexInd1, vertexInd2, 5)

        print(self.graph.getNumEdges())

        infectedList = range(0, 100)
        t = 10

        def runContactRates():
            for i in range(100):
                rates.contactRates(infectedList, t)

        cProfile.runctx('runContactRates()', globals(), locals(), self.profileFileName)
        stats = pstats.Stats(self.profileFileName)
        stats.strip_dirs().sort_stats("cumulative").print_stats(40)


    def profileInfectionProbability(self):
        rates = HIVRates(self.graph)
        t = 5

        #Getting vertices and checking parameters takes the most time 
        def runInfectionProbs():
            for i in range(10000):
                vertexInd1 = numpy.random.randint(0, self.graph.getNumVertices())
                vertexInd2 = numpy.random.randint(0, self.graph.getNumVertices())
                rates.infectionProbability(vertexInd1, vertexInd2, t)

        cProfile.runctx('runInfectionProbs()', globals(), locals(), self.profileFileName)
        stats = pstats.Stats(self.profileFileName)
        stats.strip_dirs().sort_stats("cumulative").print_stats(40)

    def profileContactTracingRate(self):
        rates = HIVRates(self.graph)

        #Create a network of sexual contacts 
        numContactEvents = 10000
        for i in range(numContactEvents):
            vertexInd1 = numpy.random.randint(0, self.graph.getNumVertices())
            vertexInd2 = numpy.random.randint(0, self.graph.getNumVertices())
            rates.contactEvent(vertexInd1, vertexInd2, 5)

        print(self.graph)
        print(self.graph.degreeDistribution())

        #Choose some individuals as being infected and then detected 
        p = 0.3
        q = 0.4
        for i in range(self.graph.getNumVertices()):
            if numpy.random.rand() < p and not self.graph.getVertex(i)[HIVVertices.stateIndex] == HIVVertices.infected:
                self.graph.getVertexList().setInfected(i, 5.0)

                if numpy.random.rand() < q:
                    self.graph.getVertexList().setDetected(i, 6.0, HIVVertices.randomDetect)

        infectedSet = self.graph.getInfectedSet()
        print(len(infectedSet))
        print(len(self.graph.getRemovedSet()))

        removedSet = self.graph.getRemovedSet()

        t = 200
        def runContactTracingRate():
            for j in range(500):
                rates.contactTracingRates(list(infectedSet), removedSet, t)

        cProfile.runctx('runContactTracingRate()', globals(), locals(), self.profileFileName)
        stats = pstats.Stats(self.profileFileName)
        stats.strip_dirs().sort_stats("cumulative").print_stats(40)

profiler = HIVRatesProfile()
#profiler.profileInfectionProbability()
#profiler.profileContactTracingRate()
profiler.profileContactRate()

#ContactRate is pretty fast now
#Profile in case that there are many contacts and infects
#Also profile other functions
#Contact tracing rate gets called a lot - need to make it faster

==> apgl-0.6.5.tar.gz: apgl-0.6.5/apgl/viroscopy/model/profile/HIVRatesProfile.py <==
import logging
import sys
import cProfile
import pstats
import numpy
import scipy
from apgl.viroscopy.model.HIVGraph import HIVGraph
from apgl.viroscopy.model.HIVRates import HIVRates
from apgl.viroscopy.model.HIVVertices import HIVVertices
from apgl.graph import *
from apgl.util import *

logging.basicConfig(stream=sys.stdout, level=logging.INFO)
numpy.random.seed(21)

class HIVRatesProfile():
    def __init__(self):
        #Total number of people in population
        self.M = 5000
        numInitialInfected = 5

        #The graph is one in which edges represent a contact
        undirected = True
        self.graph = HIVGraph(self.M, undirected)

        for i in range(self.M):
            vertex = self.graph.getVertex(i)

            #Set the infection time of a number of individuals to 0
            if i < numInitialInfected:
                vertex[HIVVertices.stateIndex] = HIVVertices.infected

        outputDirectory = PathDefaults.getOutputDir()
        directory = outputDirectory + "test/"
        self.profileFileName = directory + "profile.cprof"


    def profileContactRate(self):
        susceptibleList = list(range(1, self.graph.getNumVertices()))
        t = 10

        rates = HIVRates(self.graph)

        numContactEvents = 10000
        for i in range(numContactEvents):
            vertexInd1 = numpy.random.randint(0, self.graph.getNumVertices())
            vertexInd2 = numpy.random.randint(0, self.graph.getNumVertices())
            rates.contactEvent(vertexInd1, vertexInd2, 5)

        print((self.graph.getNumEdges()))

        infectedList = list(range(0, 100))
        t = 10

        def runContactRates():
            for i in range(100):
                rates.contactRates(infectedList, t)

        cProfile.runctx('runContactRates()', globals(), locals(), self.profileFileName)
        stats = pstats.Stats(self.profileFileName)
        stats.strip_dirs().sort_stats("cumulative").print_stats(40)


    def profileInfectionProbability(self):
        rates = HIVRates(self.graph)
        t = 5

        #Getting vertices and checking parameters takes the most time 
        def runInfectionProbs():
            for i in range(10000):
                vertexInd1 = numpy.random.randint(0, self.graph.getNumVertices())
                vertexInd2 = numpy.random.randint(0, self.graph.getNumVertices())
                rates.infectionProbability(vertexInd1, vertexInd2, t)

        cProfile.runctx('runInfectionProbs()', globals(), locals(), self.profileFileName)
        stats = pstats.Stats(self.profileFileName)
        stats.strip_dirs().sort_stats("cumulative").print_stats(40)

    def profileContactTracingRate(self):
        rates = HIVRates(self.graph)

        #Create a network of sexual contacts 
        numContactEvents = 10000
        for i in range(numContactEvents):
            vertexInd1 = numpy.random.randint(0, self.graph.getNumVertices())
            vertexInd2 = numpy.random.randint(0, self.graph.getNumVertices())
            rates.contactEvent(vertexInd1, vertexInd2, 5)

        print((self.graph))
        print((self.graph.degreeDistribution()))

        #Choose some individuals as being infected and then detected 
        p = 0.3
        q = 0.4
        for i in range(self.graph.getNumVertices()):
            if numpy.random.rand() < p and not self.graph.getVertex(i)[HIVVertices.stateIndex] == HIVVertices.infected:
                self.graph.getVertexList().setInfected(i, 5.0)

                if numpy.random.rand() < q:
                    self.graph.getVertexList().setDetected(i, 6.0, HIVVertices.randomDetect)

        infectedSet = self.graph.getInfectedSet()
        print((len(infectedSet)))
        print((len(self.graph.getRemovedSet())))

        removedSet = self.graph.getRemovedSet()

        t = 200
        def runContactTracingRate():
            for j in range(500):
                rates.contactTracingRates(list(infectedSet), removedSet, t)

        cProfile.runctx('runContactTracingRate()', globals(), locals(), self.profileFileName)
        stats = pstats.Stats(self.profileFileName)
        stats.strip_dirs().sort_stats("cumulative").print_stats(40)

profiler = HIVRatesProfile()
#profiler.profileInfectionProbability()
#profiler.profileContactTracingRate()
profiler.profileContactRate()
